@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QObject>
@@ -203,7 +203,7 @@ void MplayerEngine::readStdOut()
         {
             if (m_process->state() == QProcess::Running)
                 m_process->waitForFinished(3500);
-            emit playbackFinished();
+            StateHandler::instance()->sendFinished();
             if(!m_sources.isEmpty())
             {
                 StateHandler::instance()->dispatch(Qmmp::Stopped);
