@@ -72,7 +72,7 @@
     </message>
     <message>
         <location filename="../qmmpfiledialog.cpp" line="131"/>
-        <source>Writen by:
+        <source>Written by:
 Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
 Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autoři:
@@ -88,22 +88,22 @@ Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
 <context>
     <name>QmmpFileDialogImpl</name>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="246"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="254"/>
         <source>Add</source>
         <translation>Přidat</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="259"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="267"/>
         <source>Save</source>
         <translation>Uložit</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="273"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="281"/>
         <source>Directories</source>
         <translation>Adresáře</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="442"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="450"/>
         <source>%1 already exists.
 Do you want to replace it?</source>
         <translation>%1 již existuje.
