@@ -114,5 +114,20 @@
         <source>Volume -</source>
         <translation>音量減少</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="51"/>
+        <source>Forward 5 seconds</source>
+        <translation>5 秒すすめる</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="52"/>
+        <source>Rewind 5 seconds</source>
+        <translation>5 秒もどす</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="53"/>
+        <source>Jump to track</source>
+        <translation>トラックを指定して移動</translation>
+    </message>
 </context>
 </TS>
