@@ -57,7 +57,7 @@
     <message>
         <location filename="../settingsdialog.cpp" line="43"/>
         <source>Stop</source>
-        <translation>Stoppen</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../settingsdialog.cpp" line="44"/>
@@ -94,6 +94,21 @@
         <source>Volume -</source>
         <translation>Volume -</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="51"/>
+        <source>Forward 5 seconds</source>
+        <translation>5 Seconden Verder</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="52"/>
+        <source>Rewind 5 seconds</source>
+        <translation>5 Seconden Terug</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="53"/>
+        <source>Jump to track</source>
+        <translation>Ga naar Nummer</translation>
+    </message>
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>Global Hotkey Plugin Settings</source>
