@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <qmmp/qmmp.h>
@@ -27,6 +27,7 @@
 #include <qmmp/inputsource.h>
 #include <qmmp/inputsourcefactory.h>
 #include <qmmp/metadatamanager.h>
+#include <qmmpui/uihelper.h>
 #include "root2object.h"
 
 Root2Object::Root2Object(QObject *parent) : QDBusAbstractAdaptor(parent)
@@ -82,7 +83,7 @@ QStringList Root2Object::supportedUriSchemes() const
 
 void Root2Object::Quit()
 {
-    QMetaObject::invokeMethod(parent(), "exit");
+    UiHelper::instance()->exit();
 }
 
 void Root2Object::Raise(){}
