@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QTimer>
@@ -27,8 +27,7 @@
 #include "popupwidget.h"
 #include "notifier.h"
 
-Notifier::Notifier(QObject *parent)
-        : General(parent)
+Notifier::Notifier(QObject *parent) : QObject(parent)
 {
     m_popupWidget = 0;
     m_l = -1;
