@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QNetworkAccessManager>
@@ -261,9 +261,14 @@ void Scrobbler2::processResponse(QNetworkReply *reply)
                 m_songCache.removeFirst ();
             }
             if (!m_songCache.isEmpty()) //submit remaining songs
+            {
                 submit();
-            else
+            }
+            else 
+            {
+                syncCache(); // update the cache file to reflect the empty cache
                 updateMetaData();
+            }
         }
         else if(error_code == "9") //invalid session key
         {
