@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 
@@ -24,14 +24,11 @@
 #include <QSettings>
 #include <QFileInfo>
 #include <QDir>
-#include <cdio/cdtext.h>
-#include <cdio/track.h>
+#include <cdio/cdio.h>
 #include <cdio/cdda.h>
 #include <cdio/audio.h>
-#include <cdio/sector.h>
 #include <cdio/cd_types.h>
 #include <cdio/logging.h>
-#include <cdio/version.h>
 #include <cddb/cddb.h>
 #include <qmmp/buffer.h>
 #include <qmmp/output.h>
@@ -416,7 +413,7 @@ bool DecoderCDAudio::initialize()
     m_first_sector = tracks[track_at].first_sector;
     m_current_sector = tracks[track_at].first_sector;
     m_last_sector = tracks[track_at].last_sector;
-    StateHandler::instance()->dispatch(tracks[track_at].info.metaData()); //send metadata
+    addMetaData(tracks[track_at].info.metaData()); //send metadata
     qDebug("DecoderCDAudio: initialize succes");
     return true;
 }
