@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QFile>
@@ -36,11 +36,9 @@ CUEParser::CUEParser(const QString &url)
     QString fileName = url;
     if(url.contains("://"))
     {
-        QString p = QUrl(url).path();
-        p.replace(QString(QUrl::toPercentEncoding("#")), "#");
-        p.replace(QString(QUrl::toPercentEncoding("?")), "?");
-        p.replace(QString(QUrl::toPercentEncoding("%")), "%");
-        p.replace(QString(QUrl::toPercentEncoding(":")), ":");
+        QString p = fileName;
+        p.remove("cue://");
+        p.remove(QRegExp("#\\d+$"));
         fileName = p;
     }
     QFile file(fileName);
@@ -52,17 +50,17 @@ CUEParser::CUEParser(const QString &url)
     QTextStream textStream (&file);
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.beginGroup("CUE");
-    QTextCodec *codec = QTextCodec::codecForName(settings.value("encoding","ISO-8859-1").toByteArray ());
-    if(!codec)
-        codec = QTextCodec::codecForName("UTF-8");
     m_dirty = settings.value("dirty_cue", false).toBool();
+    QTextCodec *codec = 0;
 #ifdef WITH_ENCA
     EncaAnalyser analyser = 0;
     if(settings.value("use_enca", false).toBool())
     {
         analyser = enca_analyser_alloc(settings.value("enca_lang").toByteArray ().constData());
+        
         if(analyser)
         {
+            enca_set_threshold(analyser, 1.38);
             EncaEncoding encoding = enca_analyse(analyser,
                                                  (uchar *)file.readAll().constData(),
                                                  file.size());
@@ -76,11 +74,15 @@ CUEParser::CUEParser(const QString &url)
         }
     }
 #endif
+    if(!codec)
+        codec = QTextCodec::codecForName(settings.value("encoding","ISO-8859-1").toByteArray ());
+    if(!codec)
+        codec = QTextCodec::codecForName("UTF-8");
     settings.endGroup();
     //qDebug("CUEParser: using %s encoding", codec->name().constData());
     textStream.setCodec(codec);
     QString album, genre, date, comment, artist, file_path;
-    bool new_file = false;
+    double album_gain = 0.0, album_peak = 0.0;
 
     while (!textStream.atEnd())
     {
@@ -91,40 +93,25 @@ CUEParser::CUEParser(const QString &url)
 
         if (words[0] == "FILE")
         {
-            if(!m_infoList.isEmpty())
-            {
-                QList <FileInfo *> f_list = MetaDataManager::instance()->createPlayList(file_path, false);
-                qint64 l = f_list.isEmpty() ? 0 : f_list.at(0)->length() * 1000;
-                if (l > m_offsets.last())
-                    m_infoList.last().setLength(l - m_offsets.last());
-                else
-                    m_infoList.last().setLength(0);
-            }
             file_path = getDirtyPath(fileName, QFileInfo(fileName).dir().filePath(words[1]));
-            new_file = true;
         }
-
         else if (words[0] == "PERFORMER")
         {
-            if(m_infoList.isEmpty())
+            if(m_tracks.isEmpty())
                 artist = words[1];
             else
-                m_infoList.last().setMetaData(Qmmp::ARTIST, words[1]);
+                m_tracks.last()->info.setMetaData(Qmmp::ARTIST, words[1]);
         }
         else if (words[0] == "TITLE")
         {
-            if(m_infoList.isEmpty())
+            if(m_tracks.isEmpty())
                 album = words[1];
             else
-                m_infoList.last().setMetaData(Qmmp::TITLE, words[1]);
+                m_tracks.last()->info.setMetaData(Qmmp::TITLE, words[1]);
         }
         else if (words[0] == "TRACK")
         {
             QString path = fileName;
-            path.replace("%", QString(QUrl::toPercentEncoding("%"))); //replace special symbols
-            path.replace("#", QString(QUrl::toPercentEncoding("#")));
-            path.replace("?", QString(QUrl::toPercentEncoding("?")));
-            path.replace(":", QString(QUrl::toPercentEncoding(":")));
             FileInfo info("cue://" + path + QString("#%1").arg(words[1].toInt()));
             info.setMetaData(Qmmp::TRACK, words[1].toInt());
             info.setMetaData(Qmmp::ALBUM, album);
@@ -132,19 +119,19 @@ CUEParser::CUEParser(const QString &url)
             info.setMetaData(Qmmp::YEAR, date);
             info.setMetaData(Qmmp::COMMENT, comment);
             info.setMetaData(Qmmp::ARTIST, artist);
-            m_infoList << info;
-            m_offsets << 0;
-            m_files << file_path;
+
+            m_tracks << new CUETrack;
+            m_tracks.last()->info = info;
+            m_tracks.last()->offset = 0;
+            m_tracks.last()->replayGain.insert(Qmmp::REPLAYGAIN_ALBUM_GAIN, album_gain);
+            m_tracks.last()->replayGain.insert(Qmmp::REPLAYGAIN_ALBUM_PEAK, album_peak);
         }
         else if (words[0] == "INDEX" && words[1] == "01")
         {
-            if (m_infoList.isEmpty())
+            if (m_tracks.isEmpty())
                 continue;
-            m_offsets.last() = getLength(words[2]);
-            int c = m_infoList.count();
-            if(c > 1 && !new_file)
-                m_infoList[c - 2].setLength(m_offsets[c - 1] - m_offsets[c - 2]);
-            new_file = false;
+            m_tracks.last()->offset = getLength(words[2]);
+            m_tracks.last()->file = file_path;
         }
         else if (words[0] == "REM")
         {
@@ -156,6 +143,14 @@ CUEParser::CUEParser(const QString &url)
                 date = words[2];
             else if (words[1] == "COMMENT")
                 comment = words[2];
+            else if (words[1] == "REPLAYGAIN_ALBUM_GAIN")
+                album_gain = words[2].toDouble();
+            else if (words[1] == "REPLAYGAIN_ALBUM_PEAK")
+                album_peak = words[2].toDouble();
+            else if (words[1] == "REPLAYGAIN_TRACK_GAIN" && !m_tracks.isEmpty())
+                m_tracks.last()->replayGain.insert(Qmmp::REPLAYGAIN_TRACK_GAIN, words[2].toDouble());
+            else if (words[1] == "REPLAYGAIN_TRACK_PEAK" && !m_tracks.isEmpty())
+                m_tracks.last()->replayGain.insert(Qmmp::REPLAYGAIN_TRACK_PEAK, words[2].toDouble());
         }
     }
     file.close();
@@ -163,63 +158,89 @@ CUEParser::CUEParser(const QString &url)
     if(analyser)
         enca_analyser_free(analyser);
 #endif
-    if(m_infoList.isEmpty())
+    if(m_tracks.isEmpty())
     {
         qWarning("CUEParser: invalid cue file");
         return;
     }
-    //calculate last item length
-    QList <FileInfo *> f_list = MetaDataManager::instance()->createPlayList(file_path, false);
-    qint64 l = f_list.isEmpty() ? 0 : f_list.at(0)->length() * 1000;
-    if (l > m_offsets.last())
-        m_infoList.last().setLength(l - m_offsets.last());
-    else
-        m_infoList.last().setLength(0);
+    //skip invalid cue sheet
+    foreach(CUETrack *track, m_tracks)
+    {
+        if(!QFile::exists(track->file))
+        {
+            qDeleteAll(m_tracks);
+            m_tracks.clear();
+            break;
+        }
+    }
+    //calculate lengths
+    for(int i = 0; i < m_tracks.count(); ++i)
+    {
+        QString file_path = m_tracks[i]->file;
+        if((i < m_tracks.count() - 1) && (file_path == m_tracks[i+1]->file))
+            m_tracks[i]->info.setLength(m_tracks[i+1]->offset - m_tracks[i]->offset);
+        else
+        {
+            QList <FileInfo *> f_list = MetaDataManager::instance()->createPlayList(file_path, false);
+            qint64 l = f_list.isEmpty() ? 0 : f_list.at(0)->length() * 1000;
+            if (l > m_tracks[i]->offset)
+                m_tracks[i]->info.setLength(l - m_tracks[i]->offset);
+            else
+                m_tracks[i]->info.setLength(0);
+        }
+    }
 }
 
 CUEParser::~CUEParser()
 {
+    qDeleteAll(m_tracks);
+    m_tracks.clear();
 }
 
 QList<FileInfo*> CUEParser::createPlayList()
 {
     QList<FileInfo*> list;
-    foreach(FileInfo info, m_infoList)
+    foreach(CUETrack *track, m_tracks)
     {
-        list << new FileInfo(info);
-        list.last()->setLength(list.last()->length()/1000);
+        list << new FileInfo(track->info);
+        list.last()->setLength(track->info.length()/1000);
     }
     return list;
 }
 
-const QString CUEParser::filePath(int track)
+const QString CUEParser::filePath(int track) const
 {
-    return (track <= m_files.size()) ? m_files[track - 1] : QString();
+    return (track <= m_tracks.count()) ? m_tracks[track - 1]->file : QString();
 }
 
-qint64 CUEParser::offset(int track)
+qint64 CUEParser::offset(int track) const
 {
-    return m_offsets.at(track - 1);
+    return m_tracks.at(track - 1)->offset;
 }
 
-qint64 CUEParser::length(int track)
+qint64 CUEParser::length(int track) const
 {
-    return m_infoList.at(track - 1).length();
+    return m_tracks.at(track - 1)->info.length();
 }
 
-int CUEParser::count()
+int CUEParser::count() const
 {
-    return m_infoList.count();
+    return m_tracks.count();
 }
 
 FileInfo *CUEParser::info(int track)
 {
-    return &m_infoList[track - 1];
+    return &m_tracks.at(track - 1)->info;
 }
 
-const QString CUEParser::trackURL(int track)
+const QString CUEParser::trackURL(int track) const
 {
-    return m_infoList[track - 1].path();
+    return m_tracks.at(track - 1)->info.path();
+}
+
+const QMap<Qmmp::ReplayGainKey, double>  CUEParser::replayGain(int track) const
+{
+    return m_tracks.at(track - 1)->replayGain;
 }
 
 QStringList CUEParser::splitLine(const QString &line)
@@ -267,10 +288,9 @@ qint64 CUEParser::getLength(const QString &str)
     return 0;
 }
 
-QString CUEParser::getDirtyPath(const QString &cue, const QString &path)
+QString CUEParser::getDirtyPath(const QString &cue_path, const QString &path)
 {
-
-    if (Decoder::findByPath(path) || ! m_dirty)
+    if((QFile::exists(path) && Decoder::findByPath(path)) || !m_dirty)
         return path;
 
     QStringList candidates;
@@ -279,7 +299,7 @@ QString CUEParser::getDirtyPath(const QString &cue, const QString &path)
     {
         it.next();
         QString f = it.filePath();
-        if ((f != cue) && Decoder::findByPath(f))
+        if ((f != cue_path) && Decoder::findByPath(f))
             candidates.push_back(f);
     }
 
@@ -288,10 +308,10 @@ QString CUEParser::getDirtyPath(const QString &cue, const QString &path)
     else if (candidates.count() == 1)
         return candidates.first();
 
-    int dot = cue.lastIndexOf('.');
+    int dot = cue_path.lastIndexOf('.');
     if (dot != -1)
     {
-        QRegExp r(QRegExp::escape(cue.left(dot)) + "\\.[^\\.]+$");
+        QRegExp r(QRegExp::escape(cue_path.left(dot)) + "\\.[^\\.]+$");
 
         int index = candidates.indexOf(r);
         int rindex = candidates.lastIndexOf(r);
