@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2009 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,19 +15,17 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include <QObject>
+#include <QFile>
 #include <qmmp/buffer.h>
 #include <qmmp/output.h>
 #include <qmmp/recycler.h>
 #include <qmmp/fileinfo.h>
 #include <qmmp/decoderfactory.h>
 #include <qmmp/soundcore.h>
-
-#include <QObject>
-#include <QFile>
-
 #include "cueparser.h"
 #include "decoder_cue.h"
 
@@ -102,7 +100,7 @@ bool DecoderCUE::initialize()
     configure(m_decoder->audioParameters().sampleRate(),
               m_decoder->audioParameters().channels(),
               m_decoder->audioParameters().format());
-    setReplayGainInfo(m_decoder->replayGainInfo());
+    setReplayGainInfo(m_parser->replayGain(m_track));
     length_in_bytes = audioParameters().sampleRate() *
                       audioParameters().channels() *
                       audioParameters().sampleSize() * m_length/1000;
@@ -110,7 +108,7 @@ bool DecoderCUE::initialize()
 
     m_sz = audioParameters().sampleSize() * audioParameters().channels();
 
-    StateHandler::instance()->dispatch(m_parser->info(m_track)->metaData());
+    addMetaData(m_parser->info(m_track)->metaData());
     return true;
 }
 
@@ -160,7 +158,7 @@ qint64 DecoderCUE::read(char *data, qint64 size)
     }
 
     qint64 len2 = qMax(qint64(0), length_in_bytes - m_totalBytes);
-    len2 = (len2 / m_sz) * m_sz; //returned size must contain integer number of samples
+    len2 = (len2 / m_sz) * m_sz; //whole of samples of each channel
     m_totalBytes += len2;
     //save data of the next track
     if(m_buf)
@@ -194,7 +192,8 @@ void DecoderCUE::next()
         length_in_bytes = audioParameters().sampleRate() *
                           audioParameters().channels() *
                           audioParameters().sampleSize() * m_length/1000;
-        StateHandler::instance()->dispatch(m_parser->info(m_track)->metaData());
+        addMetaData(m_parser->info(m_track)->metaData());
+        setReplayGainInfo(m_parser->replayGain(m_track));
         m_totalBytes = 0;
     }
 }
