@@ -15,12 +15,11 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QObject>
 #include <QFile>
-#include <qmmp/statehandler.h>
 #include "decoder_ffmpeg.h"
 
 // callbacks
@@ -133,9 +132,6 @@ bool DecoderFFmpeg::initialize()
     m_stream->seekable = !input()->isSequential();
     m_stream->max_packet_size = INPUT_BUFFER_SIZE;
 
-    AVFormatParameters ap;
-    memset(&ap, 0, sizeof(ap));
-
     if(avformat_open_input(&ic, m_path.toLocal8Bit().constData(), fmt, 0) != 0)
     {
         qDebug("DecoderFFmpeg: av_open_input_stream() failed");
@@ -183,7 +179,7 @@ bool DecoderFFmpeg::initialize()
         if(track)
             metaData.insert(Qmmp::TRACK, track->value);
         metaData.insert(Qmmp::URL, m_path);
-        StateHandler::instance()->dispatch(metaData);
+        addMetaData(metaData);
     }
 
     ic->flags |= AVFMT_FLAG_GENPTS;
@@ -250,11 +246,14 @@ bool DecoderFFmpeg::initialize()
         m_bitrate = c->bit_rate/1000;
     qDebug("DecoderFFmpeg: initialize succes");
 
+#ifdef Q_OS_WIN
+    qDebug("total time = %I64d", m_totalTime);
+#else
     qDebug("total time = %lld ", m_totalTime);
+#endif
     return true;
 }
 
-
 qint64 DecoderFFmpeg::totalTime()
 {
     return m_totalTime;
@@ -551,7 +550,7 @@ bool DecoderFFmpeg::initialize()
         if(track)
             metaData.insert(Qmmp::TRACK, track->value);
         metaData.insert(Qmmp::URL, m_path);
-        StateHandler::instance()->dispatch(metaData);
+        addMetaData(metaData);
     }
 
     ic->flags |= AVFMT_FLAG_GENPTS;
