@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -117,6 +117,7 @@ const DecoderProperties DecoderFFmpegFactory::properties() const
     properties.hasAbout = true;
     properties.hasSettings = true;
     properties.noInput = false;
+    properties.priority = 10;
     return properties;
 }
 
