@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 
@@ -270,23 +270,15 @@ bool DecoderFLAC::initialize()
 {
     if (!data()->input)
     {
-        QString p = m_path;
         if (m_path.startsWith("flac://")) //embeded cue track
         {
-            p = QUrl(m_path).path();
-            if (!p.endsWith(".flac"))
-            {
-                qWarning("DecoderFLAC: invalid url.");
-                return false;
-            }
-            p.replace(QString(QUrl::toPercentEncoding("#")), "#");
-            p.replace(QString(QUrl::toPercentEncoding("?")), "?");
-            p.replace(QString(QUrl::toPercentEncoding("%")), "%");
-            p.replace(QString(QUrl::toPercentEncoding(":")), ":");
-            TagLib::FLAC::File fileRef(p.toLocal8Bit ());
+            QString p = m_path;
+            p.remove("flac://");
+            p.remove(QRegExp("#\\d+$"));
+            TagLib::FLAC::File fileRef(p.toLocal8Bit().constData());
             //looking for cuesheet comment
             TagLib::Ogg::XiphComment *xiph_comment = fileRef.xiphComment();
-            QList <FileInfo*> list;
+
             if (xiph_comment && xiph_comment->fieldListMap().contains("CUESHEET"))
             {
                 qDebug("DecoderFLAC: using cuesheet xiph comment.");
@@ -306,9 +298,7 @@ bool DecoderFLAC::initialize()
                               QString::fromUtf8(xiph_comment->fieldListMap()["DISCNUMBER"].toString().toCString(true)).trimmed());
                 }
                 QMap<Qmmp::MetaData, QString> metaData = m_parser->info(m_track)->metaData();
-                StateHandler::instance()->dispatch(metaData); //send metadata
-                ReplayGainReader rg(p);
-                setReplayGainInfo(rg.replayGainInfo());
+                addMetaData(metaData); //send metadata
             }
             else
             {
@@ -431,6 +421,7 @@ bool DecoderFLAC::initialize()
         length_in_bytes = audioParameters().sampleRate() *
                           audioParameters().channels() *
                           audioParameters().sampleSize() * m_length/1000;
+        setReplayGainInfo(m_parser->replayGain(m_track));
         seek(0);
     }
     m_totalBytes = 0;
@@ -546,7 +537,8 @@ void DecoderFLAC::next()
         length_in_bytes = audioParameters().sampleRate() *
                           audioParameters().channels() *
                           audioParameters().sampleSize() * m_length/1000;
-        StateHandler::instance()->dispatch(m_parser->info(m_track)->metaData());
+        addMetaData(m_parser->info(m_track)->metaData());
+        setReplayGainInfo(m_parser->replayGain(m_track));
         m_totalBytes = 0;
     }
 }
