@@ -6,32 +6,32 @@
     <message>
         <location filename="../decodergmefactory.cpp" line="48"/>
         <source>GME Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>GME Module</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="51"/>
         <source>Game Music Files</source>
-        <translation type="unfinished"></translation>
+        <translation>Spel Muziek Bestanden</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="116"/>
         <source>About GME Audio Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Over de GME Audio Module</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="117"/>
         <source>Qmmp GME Audio Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>GME Audio Module voor Qmmp</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="118"/>
         <source>This plugin uses Game_Music_Emu library to play game music files</source>
-        <translation type="unfinished"></translation>
+        <translation>Deze module faciliteert in het afspelen van spelmuziek door gebruik van de Game_Music_Emu bibliotheek</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="119"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation type="unfinished">Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 </TS>
