@@ -1,37 +1,37 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="zh_CN">
+<TS version="2.0" language="zh_CN" sourcelanguage="zh_CN">
 <context>
     <name>DecoderGmeFactory</name>
     <message>
         <location filename="../decodergmefactory.cpp" line="48"/>
         <source>GME Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>GME 插件</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="51"/>
         <source>Game Music Files</source>
-        <translation type="unfinished"></translation>
+        <translation>Game 音乐文件</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="116"/>
         <source>About GME Audio Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>关于 GME 音频插件</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="117"/>
         <source>Qmmp GME Audio Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Qmmp GME 音频插件</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="118"/>
         <source>This plugin uses Game_Music_Emu library to play game music files</source>
-        <translation type="unfinished"></translation>
+        <translation>此插件使用 Game_Music_Emu 库来播放 game 音乐文件</translation>
     </message>
     <message>
         <location filename="../decodergmefactory.cpp" line="119"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation type="unfinished">作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 </TS>
