@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QObject>
@@ -56,8 +56,19 @@ OutputALSA::~OutputALSA()
     free (pcm_name);
 }
 
-void OutputALSA::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
+bool OutputALSA::initialize(quint32 freq, int chan, Qmmp::AudioFormat format)
 {
+    m_inited = false;
+
+    if (pcm_handle)
+        return false;
+
+    if (snd_pcm_open(&pcm_handle, pcm_name, SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK) < 0)
+    {
+        qWarning ("OutputALSA: Error opening PCM device %s", pcm_name);
+        return false;
+    }
+
     // we need to configure
 
     uint rate = freq; /* Sample rate */
@@ -80,7 +91,7 @@ void OutputALSA::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
     if ((err = snd_pcm_hw_params_any(pcm_handle, hwparams)) < 0)
     {
         qWarning("OutputALSA: Can not read configuration for PCM device: %s", snd_strerror(err));
-        return;
+        return false;
     }
     if (m_use_mmap)
     {
@@ -95,7 +106,7 @@ void OutputALSA::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
         if ((err = snd_pcm_hw_params_set_access(pcm_handle, hwparams, SND_PCM_ACCESS_RW_INTERLEAVED)) < 0)
         {
             qWarning("OutputALSA: Error setting access: %s", snd_strerror(err));
-            return;
+            return false;
         }
     }
     snd_pcm_format_t alsa_format = SND_PCM_FORMAT_UNKNOWN;
@@ -115,19 +126,19 @@ void OutputALSA::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
         break;
     default:
         qWarning("OutputALSA: unsupported format detected");
-        return;
+        return false;
     }
     if ((err = snd_pcm_hw_params_set_format(pcm_handle, hwparams, alsa_format)) < 0)
     {
         qDebug("OutputALSA: Error setting format: %s", snd_strerror(err));
-        return;
+        return false;
     }
     exact_rate = rate;
 
     if ((err = snd_pcm_hw_params_set_rate_near(pcm_handle, hwparams, &exact_rate, 0)) < 0)
     {
         qWarning("OutputALSA: Error setting rate: %s", snd_strerror(err));
-        return;
+        return false;
     }
     if (rate != exact_rate)
     {
@@ -137,22 +148,22 @@ void OutputALSA::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
     if ((err = snd_pcm_hw_params_set_channels_near(pcm_handle, hwparams, &c)) < 0)
     {
         qWarning("OutputALSA: Error setting channels: %s", snd_strerror(err));
-        return;
+        return false;
     }
     if ((err = snd_pcm_hw_params_set_period_time_near(pcm_handle, hwparams, &period_time ,0)) < 0)
     {
         qWarning("OutputALSA: Error setting period time: %s", snd_strerror(err));
-        return;
+        return false;
     }
     if ((err = snd_pcm_hw_params_set_buffer_time_near(pcm_handle, hwparams, &buffer_time ,0)) < 0)
     {
         qWarning("OutputALSA: Error setting buffer time: %s", snd_strerror(err));
-        return;
+        return false;
     }
     if ((err = snd_pcm_hw_params(pcm_handle, hwparams)) < 0)
     {
         qWarning("OutputALSA: Error setting HW params: %s", snd_strerror(err));
-        return;
+        return false;
     }
     //read some alsa parameters
     snd_pcm_uframes_t buffer_size = 0;
@@ -160,12 +171,12 @@ void OutputALSA::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
     if ((err = snd_pcm_hw_params_get_buffer_size(hwparams, &buffer_size)) < 0)
     {
         qWarning("OutputALSA: Error reading buffer size: %s", snd_strerror(err));
-        return;
+        return false;
     }
     if ((err = snd_pcm_hw_params_get_period_size(hwparams, &period_size, 0)) < 0)
     {
         qWarning("OutputALSA: Error reading period size: %s", snd_strerror(err));
-        return;
+        return false;
     }
     //swparams
     snd_pcm_sw_params_alloca(&swparams);
@@ -176,31 +187,17 @@ void OutputALSA::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
     if ((err = snd_pcm_sw_params(pcm_handle, swparams)) < 0)
     {
         qWarning("OutputALSA: Error setting SW params: %s", snd_strerror(err));
-        return;
+        return false;
     }
     //setup needed values
     m_bits_per_frame = snd_pcm_format_physical_width(alsa_format) * chan;
     m_chunk_size = period_size;
     m_can_pause = snd_pcm_hw_params_can_pause(hwparams) && use_pause;
     qDebug("OutputALSA: can pause: %d", m_can_pause);
-    Output::configure(freq, chan, format); //apply configuration
+    configure(freq, chan, format); //apply configuration
     //create alsa prebuffer;
     m_prebuf_size = /*QMMP_BUFFER_SIZE + */m_bits_per_frame * m_chunk_size / 8;
     m_prebuf = (uchar *)malloc(m_prebuf_size);
-}
-
-bool OutputALSA::initialize()
-{
-    m_inited = false;
-
-    if (pcm_handle)
-        return false;
-
-    if (snd_pcm_open(&pcm_handle, pcm_name, SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK) < 0)
-    {
-        qWarning ("OutputALSA: Error opening PCM device %s", pcm_name);
-        return false;
-    }
 
     m_inited = true;
     return true;
@@ -362,7 +359,7 @@ void OutputALSA::uninitialize()
 }
 /* ****** MIXER ******* */
 
-VolumeControlALSA::VolumeControlALSA(QObject *parent) : VolumeControl(parent)
+VolumeALSA::VolumeALSA()
 {
     //alsa mixer
     mixer = 0;
@@ -373,42 +370,40 @@ VolumeControlALSA::VolumeControlALSA(QObject *parent) : VolumeControl(parent)
 }
 
 
-VolumeControlALSA::~VolumeControlALSA()
+VolumeALSA::~VolumeALSA()
 {
     if (mixer)
         snd_mixer_close(mixer);
 }
 
-void VolumeControlALSA::setVolume(int l, int r)
+void VolumeALSA::setVolume(int channel, int value)
 {
-
     if (!pcm_element)
         return;
 
-    snd_mixer_selem_set_playback_volume(pcm_element,
-                                        SND_MIXER_SCHN_FRONT_LEFT, l);
-    snd_mixer_selem_set_playback_volume(pcm_element,
-                                        SND_MIXER_SCHN_FRONT_RIGHT, r);
+    _snd_mixer_selem_channel_id channel_id = SND_MIXER_SCHN_FRONT_LEFT;
+    if(channel == Volume::RIGHT_CHANNEL)
+        channel_id = SND_MIXER_SCHN_FRONT_RIGHT;
+
+    snd_mixer_selem_set_playback_volume(pcm_element, channel_id, value);
 }
 
-void VolumeControlALSA::volume(int *l, int *r)
+int VolumeALSA::volume(int channel)
 {
     if (!pcm_element)
-        return;
+        return 0;
 
-    long ll = *l, lr = *r;
+    _snd_mixer_selem_channel_id channel_id = SND_MIXER_SCHN_FRONT_LEFT;
+    if(channel == Volume::RIGHT_CHANNEL)
+        channel_id = SND_MIXER_SCHN_FRONT_RIGHT;
+
+    long value = 0;
     snd_mixer_handle_events(mixer);
-    snd_mixer_selem_get_playback_volume(pcm_element,
-                                        SND_MIXER_SCHN_FRONT_LEFT, &ll);
-    snd_mixer_selem_get_playback_volume(pcm_element,
-                                        SND_MIXER_SCHN_FRONT_RIGHT, &lr);
-    *l = ll;
-    *r = lr;
+    snd_mixer_selem_get_playback_volume(pcm_element, channel_id, &value);
+    return value;
 }
 
-
-
-int VolumeControlALSA::setupMixer(QString card, QString device)
+int VolumeALSA::setupMixer(QString card, QString device)
 {
     char *name;
     int err, index;
@@ -442,7 +437,7 @@ int VolumeControlALSA::setupMixer(QString card, QString device)
     return 0;
 }
 
-void VolumeControlALSA::parseMixerName(char *str, char **name, int *index)
+void VolumeALSA::parseMixerName(char *str, char **name, int *index)
 {
     char *end;
 
@@ -462,7 +457,7 @@ void VolumeControlALSA::parseMixerName(char *str, char **name, int *index)
     }
 }
 
-snd_mixer_elem_t* VolumeControlALSA::getMixerElem(snd_mixer_t *mixer, char *name, int index)
+snd_mixer_elem_t* VolumeALSA::getMixerElem(snd_mixer_t *mixer, char *name, int index)
 {
     snd_mixer_selem_id_t* selem_id;
     snd_mixer_elem_t* elem;
@@ -478,7 +473,7 @@ snd_mixer_elem_t* VolumeControlALSA::getMixerElem(snd_mixer_t *mixer, char *name
     return elem;
 }
 
-int VolumeControlALSA::getMixer(snd_mixer_t **mixer, QString card)
+int VolumeALSA::getMixer(snd_mixer_t **mixer, QString card)
 {
     char *dev;
     int err;
