@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef   OUTPUTALSA_H
@@ -31,7 +31,7 @@ extern "C"
 }
 
 #include <qmmp/output.h>
-#include <qmmp/volumecontrol.h>
+#include <qmmp/volume.h>
 
 
 class OutputALSA : public Output
@@ -41,8 +41,7 @@ public:
     OutputALSA(QObject * parent = 0);
     ~OutputALSA();
 
-    bool initialize();
-    void configure(quint32, int, Qmmp::AudioFormat format);
+    bool initialize(quint32, int, Qmmp::AudioFormat format);
     qint64 latency();
 
 private:
@@ -71,17 +70,14 @@ private:
     bool m_can_pause;
 };
 
-class VolumeControlALSA : public VolumeControl
+class VolumeALSA : public Volume
 {
-    Q_OBJECT
 public:
-    VolumeControlALSA(QObject *parent = 0);
-    ~VolumeControlALSA();
+    VolumeALSA();
+    ~VolumeALSA();
 
-    void setVolume(int left, int right) ;
-
-protected:
-    void volume(int *left, int *right);
+    void setVolume(int channel, int value);
+    int volume(int channel);
 
 private:
     //alsa mixer
