@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -40,9 +40,9 @@ Output* OutputALSAFactory::create(QObject* parent)
     return new OutputALSA(parent);
 }
 
-VolumeControl *OutputALSAFactory::createVolumeControl(QObject *parent)
+Volume *OutputALSAFactory::createVolume()
 {
-    return new VolumeControlALSA(parent);
+    return new VolumeALSA();
 }
 
 void OutputALSAFactory::showSettings(QWidget* parent)
