@@ -1655,18 +1655,27 @@ JACK_OpenEx(int *deviceID, unsigned int bits_per_channel,
   /* FIXME: maybe we should keep different latency values for input vs output? */
   if(drv->num_output_channels > 0)
   {
+#ifdef JACK_NEW_API
     jack_latency_range_t range;
     jack_port_get_latency_range(drv->output_port[0], JackPlaybackLatency, &range);
     periods = range.max / periodSize;
+#else
+    periods = jack_port_get_total_latency(drv->client, drv->output_port[0]) / periodSize;
+#endif
+
     drv->latencyMS = periodSize * periods * 1000 / (drv->jack_sample_rate *
                                                     (drv->bits_per_channel / 8 *
                                                      drv->num_output_channels));
   }
   else if(drv->num_input_channels > 0)
   {
+#ifdef JACK_NEW_API
     jack_latency_range_t range;
     jack_port_get_latency_range(drv->output_port[0], JackPlaybackLatency, &range);
     periods = range.max / periodSize;
+#else
+    periods = jack_port_get_total_latency(drv->client, drv->output_port[0]) / periodSize;
+#endif
     drv->latencyMS =
       periodSize * periods * 1000 / (drv->jack_sample_rate *
                                      (drv->bits_per_channel / 8 *
@@ -2546,9 +2555,13 @@ JACK_GetJackOutputLatency(int deviceID)
 
   if(drv->client && drv->num_input_channels)
   {
+#ifdef JACK_NEW_API
     jack_latency_range_t range;
     jack_port_get_latency_range(drv->output_port[0], JackCaptureLatency, &range);
     return_val = range.max;
+#else
+    return_val = jack_port_get_total_latency(drv->client, drv->output_port[0]);
+#endif
   }
 
   TRACE("got latency of %ld frames\n", return_val);
@@ -2566,9 +2579,14 @@ JACK_GetJackInputLatency(int deviceID)
 
   if(drv->client && drv->num_input_channels)
   {
+#ifdef JACK_NEW_API
     jack_latency_range_t range;
     jack_port_get_latency_range(drv->output_port[0], JackPlaybackLatency, &range);
     return_val = range.max;
+#else
+    return_val = jack_port_get_total_latency(drv->client, drv->output_port[0]);
+#endif
+
   }
   TRACE("got latency of %ld frames\n", return_val);
 
