@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -39,7 +39,7 @@ Output* OutputJACKFactory::create(QObject* parent)
     return new OutputJACK(parent);
 }
 
-VolumeControl *OutputJACKFactory::createVolumeControl(QObject *)
+Volume *OutputJACKFactory::createVolume()
 {
     return 0;
 }
