@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #ifndef OUTPUTJACKFACTORY_H
 #define OUTPUTJACKFACTORY_H
@@ -30,16 +30,15 @@
 #include <qmmp/outputfactory.h>
 
 
-class OutputJACKFactory : public QObject,
-                          OutputFactory
+class OutputJACKFactory : public QObject, OutputFactory
 {
 Q_OBJECT
-Q_INTERFACES(OutputFactory);
+Q_INTERFACES(OutputFactory)
 
 public:
     const OutputProperties properties() const;
     Output* create(QObject* parent);
-    VolumeControl *createVolumeControl(QObject *parent);
+    Volume *createVolume();
     void showSettings(QWidget* parent);
     void showAbout(QWidget *parent);
     QTranslator *createTranslator(QObject *parent);
