@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010 by Ilya Kotov                                      *
+ *   Copyright (C) 2010-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include "outputnull.h"
@@ -29,7 +29,7 @@ OutputNull::OutputNull(QObject * parent) : Output(parent)
 OutputNull::~OutputNull()
 {}
 
-void OutputNull::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
+bool OutputNull::initialize(quint32 freq, int chan, Qmmp::AudioFormat format)
 {
     switch (format)
     {
@@ -44,11 +44,7 @@ void OutputNull::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
     default:
          m_bytes_per_second = freq * chan * 2;
     }
-    Output::configure(freq, chan, format);
-}
-
-bool OutputNull::initialize()
-{
+    configure(freq, chan, format);
     return true;
 }
 
