@@ -16,7 +16,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QApplication>
@@ -60,8 +60,26 @@ OutputOSS::~OutputOSS()
     }
 }
 
-void OutputOSS::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
+void OutputOSS::post()
 {
+    ioctl(m_audio_fd, SNDCTL_DSP_POST, 0);
+}
+
+void OutputOSS::sync()
+{
+    ioctl(m_audio_fd, SNDCTL_DSP_SYNC, 0);
+}
+
+bool OutputOSS::initialize(quint32 freq, int chan, Qmmp::AudioFormat format)
+{
+    m_audio_fd = open(m_audio_device.toAscii(), O_WRONLY);
+
+    if (m_audio_fd < 0)
+    {
+        qWarning("OSSOutput: failed to open output device '%s'", qPrintable(m_audio_device));
+        return false;
+    }
+
     ioctl(m_audio_fd, SNDCTL_DSP_RESET, 0);
 
     int p;
@@ -79,7 +97,7 @@ void OutputOSS::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
         break;
     default:
         qWarning("OutputOSS: unsupported audio format");
-        return;
+        return false;
     }
 
     if (ioctl(m_audio_fd, SNDCTL_DSP_SETFMT, &p) == -1)
@@ -103,28 +121,7 @@ void OutputOSS::configure(quint32 freq, int chan, Qmmp::AudioFormat format)
 
     ioctl(m_audio_fd, SNDCTL_DSP_RESET, 0);
 
-    Output::configure(freq, chan, format);
-}
-
-void OutputOSS::post()
-{
-    ioctl(m_audio_fd, SNDCTL_DSP_POST, 0);
-}
-
-void OutputOSS::sync()
-{
-    ioctl(m_audio_fd, SNDCTL_DSP_SYNC, 0);
-}
-
-bool OutputOSS::initialize()
-{
-    m_audio_fd = open(m_audio_device.toAscii(), O_WRONLY);
-
-    if (m_audio_fd < 0)
-    {
-        qWarning("OSSOutput: failed to open output device '%s'", qPrintable(m_audio_device));
-        return false;
-    }
+    configure(freq, chan, format);
     return true;
 }
 
@@ -151,7 +148,7 @@ void OutputOSS::reset()
 }
 
 /***** MIXER *****/
-VolumeControlOSS::VolumeControlOSS(QObject *parent) : VolumeControl(parent)
+VolumeOSS::VolumeOSS()
 {
     m_master = true;
     m_mixer_fd = -1;
@@ -161,7 +158,7 @@ VolumeControlOSS::VolumeControlOSS(QObject *parent) : VolumeControl(parent)
 
 }
 
-VolumeControlOSS::~VolumeControlOSS()
+VolumeOSS::~VolumeOSS()
 {
     if (m_mixer_fd >= 0)
     {
@@ -170,11 +167,14 @@ VolumeControlOSS::~VolumeControlOSS()
     }
 }
 
-void VolumeControlOSS::setVolume(int l, int r)
+void VolumeOSS::setVolume(int channel, int value)
 {
     if (m_mixer_fd < 0)
         return;
-    int v;
+
+    int l = (channel == Volume::LEFT_CHANNEL) ? value : volume(Volume::LEFT_CHANNEL);
+    int r = (channel == Volume::RIGHT_CHANNEL) ? value : volume(Volume::RIGHT_CHANNEL);
+
     long cmd;
     int devs = 0;
     ioctl(m_mixer_fd, SOUND_MIXER_READ_DEVMASK, &devs);
@@ -187,16 +187,14 @@ void VolumeControlOSS::setVolume(int l, int r)
         //close(mifd);
         return;
     }
-    v = (r << 8) | l;
+    int v = (r << 8) | l;
     ioctl(m_mixer_fd, cmd, &v);
 }
 
-void VolumeControlOSS::volume(int *ll,int *rr)
+int VolumeOSS::volume(int channel)
 {
-    *ll = 0;
-    *rr = 0;
     if(m_mixer_fd < 0)
-        return;
+        return 0;
     int cmd;
     int v, devs = 0;
     ioctl(m_mixer_fd, SOUND_MIXER_READ_DEVMASK, &devs);
@@ -206,19 +204,15 @@ void VolumeControlOSS::volume(int *ll,int *rr)
     else if ((devs & SOUND_MASK_VOLUME) && m_master)
         cmd = SOUND_MIXER_READ_VOLUME;
     else
-        return;
+        return 0;
 
     ioctl(m_mixer_fd, cmd, &v);
-    *ll = (v & 0xFF00) >> 8;
-    *rr = (v & 0x00FF);
-
-    *ll = (*ll > 100) ? 100 : *ll;
-    *rr = (*rr > 100) ? 100 : *rr;
-    *ll = (*ll < 0) ? 0 : *ll;
-    *rr = (*rr < 0) ? 0 : *rr;
+    if(channel == Volume::LEFT_CHANNEL)
+        return (v & 0xFF00) >> 8;
+    return (v & 0x00FF);
 }
 
-void VolumeControlOSS::openMixer()
+void VolumeOSS::openMixer()
 {
     if (m_mixer_fd >= 0)
         return;
