@@ -16,7 +16,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 
@@ -26,7 +26,7 @@
 class OutputOSS;
 
 #include <qmmp/output.h>
-#include <qmmp/volumecontrol.h>
+#include <qmmp/volume.h>
 
 class OutputOSS : public Output
 {
@@ -35,8 +35,7 @@ public:
     OutputOSS(QObject * parent = 0);
     virtual ~OutputOSS();
 
-    bool initialize();
-    void configure(quint32, int, Qmmp::AudioFormat format);
+    bool initialize(quint32, int, Qmmp::AudioFormat format);
     qint64 latency();
 
 private:
@@ -44,8 +43,7 @@ private:
     qint64 writeAudio(unsigned char *data, qint64 maxSize);
     void drain();
     void reset();
-
-private:
+    //oss
     void post();
     void sync();
     QString m_audio_device;
@@ -54,15 +52,14 @@ private:
     long bl, br;
 };
 
-class VolumeControlOSS : public VolumeControl
+class VolumeOSS : public Volume
 {
-    Q_OBJECT
 public:
-    VolumeControlOSS(QObject *parent = 0);
-    ~VolumeControlOSS();
+    VolumeOSS();
+    ~VolumeOSS();
 
-    void setVolume(int left, int right);
-    void volume(int *left, int *right);
+    void setVolume(int channel, int value);
+    int volume(int channel);
 
 private:
     //oss mixer
