@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -40,9 +40,9 @@ const OutputProperties OutputOSSFactory::properties() const
     return properties;
 }
 
-VolumeControl *OutputOSSFactory::createVolumeControl(QObject *parent)
+Volume *OutputOSSFactory::createVolume()
 {
-    return new VolumeControlOSS(parent);
+    return new VolumeOSS;
 }
 
 void OutputOSSFactory::showSettings(QWidget* parent)
