@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef OUTPUTPULSEAUDIO_H
@@ -37,8 +37,7 @@ public:
     OutputPulseAudio(QObject * parent = 0);
     ~OutputPulseAudio();
 
-    bool initialize();
-    void configure(quint32, int, Qmmp::AudioFormat format);
+    bool initialize(quint32, int, Qmmp::AudioFormat format);
     qint64 latency();
 
 private:
@@ -49,9 +48,7 @@ private:
 
     // helper functions
     void uninitialize();
-
     pa_simple *m_connection;
 };
 
-
 #endif // OUTPUTPULSEAUDIO_H
