@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2008 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -39,7 +39,7 @@ Output* OutputPulseAudioFactory::create(QObject* parent)
     return new OutputPulseAudio(parent);
 }
 
-VolumeControl *OutputPulseAudioFactory::createVolumeControl(QObject *)
+Volume *OutputPulseAudioFactory::createVolume()
 {
     return 0;
 }
