@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include <QApplication>
 #include <QStringList>
@@ -27,6 +27,7 @@
 #include <qmmp/qmmpsettings.h>
 #include <qmmp/qmmp.h>
 #include <qmmp/statehandler.h>
+#include <qmmp/inputsource.h>
 #include "httpstreamreader.h"
 
 //curl callbacks
@@ -128,6 +129,8 @@ HttpStreamReader::HttpStreamReader(const QString &url, QObject *parent)
     m_analyser = 0;
     if(settings.value("use_enca", false).toBool())
         m_analyser = enca_analyser_alloc(settings.value("enca_lang").toByteArray ().constData());
+    if(m_analyser)
+        enca_set_threshold(m_analyser, 1.38);
 #endif
     settings.endGroup();
 }
@@ -370,7 +373,8 @@ void HttpStreamReader::checkBuffer()
                 metaData.insert(Qmmp::GENRE, m_stream.header.value("icy-genre"));
             }
             metaData.insert(Qmmp::URL, m_url);
-            StateHandler::instance()->dispatch(metaData);
+            (qobject_cast<InputSource *>(parent()))->addMetaData(metaData);
+            (qobject_cast<InputSource *>(parent()))->addStreamInfo(m_stream.header);
         }
         emit ready();
     }
@@ -447,7 +451,7 @@ void HttpStreamReader::parseICYMetaData(char *data, qint64 size)
                 metaData.insert(Qmmp::TITLE, m_stream.header.value("icy-name"));
             metaData.insert(Qmmp::GENRE, m_stream.header.value("icy-genre"));
             metaData.insert(Qmmp::URL, m_url);
-            StateHandler::instance()->dispatch(metaData);
+            (qobject_cast<InputSource *>(parent()))->addMetaData(metaData);
             m_meta_sent = true;
             break;
         }
