@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #ifndef HTTPSTREAMREADER_H
 #define HTTPSTREAMREADER_H
@@ -25,7 +25,7 @@
 #include <QUrl>
 #include <QMutex>
 #include <QString>
-#include <QMap>
+#include <QHash>
 #include <QThread>
 #include <curl/curl.h>
 #ifdef WITH_ENCA
@@ -45,7 +45,7 @@ struct HttpStreamData
     long buf_fill;
     QString content_type;
     bool aborted;
-    QMap <QString, QString> header;
+    QHash <QString, QString> header;
     bool icy_meta_data;
     int icy_metaint;
 };
