@@ -74,22 +74,22 @@
     <message>
         <location filename="../settingsdialog.ui" line="139"/>
         <source>50 FPS</source>
-        <translation>50 Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="144"/>
         <source>25 FPS</source>
-        <translation>25 Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="149"/>
         <source>10 FPS</source>
-        <translation>10 Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="154"/>
         <source>5 FPS</source>
-        <translation>5 Hz</translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="171"/>
