@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,14 +15,14 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef ABSTRACTENGINE_H
 #define ABSTRACTENGINE_H
 
 #include <QMutex>
-#include <QWaitCondition>
+//#include <QWaitCondition>
 #include <QThread>
 #include <QStringList>
 #include "enginefactory.h"
@@ -75,10 +75,6 @@ public:
      * Returns mutex pointer.
      */
     QMutex *mutex();
-    /*!
-     * Returns wait condition pointer.
-     */
-    QWaitCondition *cond();
     /*!
      * Creates Engine object.
      * @param s InputSource object.
@@ -106,29 +102,22 @@ public:
      */
     static bool isEnabled(EngineFactory* factory);
     /*!
-     * Returns a list of engine plugin files.
+     * Returns plugin file path.
+     * @param factory Engine plugin factory.
      */
-    static QStringList files();
+    static QString file(EngineFactory *factory);
     /*!
      * Returns a list of supported protocols (including meta-protocols).
      * This fuction ignores disabled engines.
      */
     static QStringList protocols();
 
-signals:
-    /*!
-     * Emitted when the decoder has finished playback.
-     */
-    void playbackFinished();
-
 private:
     QMutex m_mutex;
-    QWaitCondition m_waitCondition;
-
     static void checkFactories();
     static QList<EngineFactory*> *m_factories;
     static QList<EngineFactory*> *m_disabledFactories;
-    static QStringList m_files;
+    static QHash <EngineFactory*, QString> *m_files;
 };
 
 
