@@ -27,7 +27,9 @@ extern "C"
 #include "decoder.h"
 
 Decoder::Decoder(QIODevice *input) : m_input(input)
-{}
+{
+    m_hasMetaData = false;
+}
 
 Decoder::~Decoder()
 {}
@@ -60,16 +62,39 @@ QMap<Qmmp::ReplayGainKey, double> Decoder::replayGainInfo() const
     return m_rg;
 }
 
+void Decoder::addMetaData(const QMap<Qmmp::MetaData, QString> &metaData)
+{
+    m_metaData = metaData;
+    m_hasMetaData = true;
+}
+
 QIODevice *Decoder::input()
 {
     return m_input;
 }
 
+bool Decoder::hasMetaData() const
+{
+    return m_hasMetaData;
+}
+
+QMap<Qmmp::MetaData, QString> Decoder::takeMetaData()
+{
+    m_hasMetaData = false;
+    return m_metaData;
+}
+
 // static methods
 QList<DecoderFactory*> *Decoder::m_factories = 0;
 QList<DecoderFactory*> *Decoder::m_disabledFactories = 0;
 DecoderFactory *Decoder::m_lastFactory = 0;
-QStringList Decoder::m_files;
+QHash <DecoderFactory*, QString> *Decoder::m_files = 0;
+
+//sort factories by priority
+static bool _decoderLessComparator(DecoderFactory* f1, DecoderFactory* f2)
+{
+    return f1->properties().priority < f2->properties().priority;
+}
 
 void Decoder::checkFactories()
 {
@@ -78,9 +103,9 @@ void Decoder::checkFactories()
         QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
         QStringList disabledNames  = settings.value("Decoder/disabled_plugins").toStringList ();
 
-        m_files.clear();
         m_factories = new QList<DecoderFactory *>;
         m_disabledFactories = new QList<DecoderFactory *>;
+        m_files = new QHash <DecoderFactory*, QString>;
 
         QDir pluginsDir (Qmmp::pluginsPath());
         pluginsDir.cd("Input");
@@ -93,13 +118,14 @@ void Decoder::checkFactories()
             else
                 qWarning("Decoder: %s", qPrintable(loader.errorString ()));
             DecoderFactory *factory = 0;
+
             if (plugin)
                 factory = qobject_cast<DecoderFactory *>(plugin);
 
             if (factory)
             {
                 m_factories->append(factory);
-                m_files << pluginsDir.absoluteFilePath(fileName);
+                m_files->insert(factory, pluginsDir.absoluteFilePath(fileName));
                 qApp->installTranslator(factory->createTranslator(qApp));
                 if(disabledNames.contains(factory->properties().shortName))
                     m_disabledFactories->append(factory);
@@ -117,17 +143,19 @@ void Decoder::checkFactories()
                 disabledNames.removeAll(name);
         }
         settings.setValue("Decoder/disabled_plugins",disabledNames);
+        qSort(m_factories->begin(), m_factories->end(), _decoderLessComparator);
     }
 }
 
-QStringList Decoder::files()
+QString Decoder::file(DecoderFactory *factory)
 {
     checkFactories();
-    return m_files;
+    return m_files->value(factory);
 }
 
 QStringList Decoder::protocols()
 {
+    checkFactories();
     QStringList protocolsList;
     foreach(DecoderFactory *f, *m_factories)
     {
@@ -138,10 +166,38 @@ QStringList Decoder::protocols()
     return protocolsList;
 }
 
-DecoderFactory *Decoder::findByPath(const QString& source)
+DecoderFactory *Decoder::findByPath(const QString& source, bool useContent)
 {
     checkFactories();
     DecoderFactory *fact = m_lastFactory;
+    if(useContent)
+    {
+        QFile file(source);
+        if(!file.open(QIODevice::ReadOnly))
+        {
+            qWarning("Decoder: file open error: %s", qPrintable(file.errorString()));
+            return 0;
+        }
+        QByteArray array = file.read(8192);
+        QBuffer buffer(&array);
+        buffer.open(QIODevice::ReadOnly);
+
+        //try last factory with stream based input or local files support
+        if (fact && isEnabled(fact) && (!fact->properties().noInput ||
+                                        fact->properties().protocols.contains("file")))
+            return fact;
+
+        foreach(DecoderFactory *fact, *m_factories)
+        {
+            if(fact->properties().noInput && !fact->properties().protocols.contains("file"))
+                continue;
+
+            if (isEnabled(fact) && fact->canDecode(&buffer))
+            {
+                return fact;
+            }
+        }
+    }
     if (fact && fact->supports(source) && isEnabled(fact)) //try last factory
         return fact;
     foreach(fact, *m_factories)
@@ -163,7 +219,8 @@ DecoderFactory *Decoder::findByMime(const QString& type)
     DecoderFactory *fact;
     foreach(fact, *m_factories)
     {
-        if (isEnabled(fact) && fact->properties().contentTypes.contains(type))
+        if (isEnabled(fact) && !fact->properties().noInput
+                && fact->properties().contentTypes.contains(type))
             return fact;
     }
     return 0;
@@ -174,7 +231,7 @@ DecoderFactory *Decoder::findByContent(QIODevice *input)
     checkFactories();
     foreach(DecoderFactory *fact, *m_factories)
     {
-        if (isEnabled(fact) && fact->canDecode(input))
+        if (isEnabled(fact) && !fact->properties().noInput && fact->canDecode(input))
         {
             return fact;
         }
