@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef DECODERFACTORY_H
@@ -48,6 +48,7 @@ public:
         hasSettings = false;
         noInput = false;
         noOutput = false;
+        priority = 0;
     }
     QString name;             /*!< Input plugin full name */
     QString shortName;        /*!< Input plugin short name for internal usage */
@@ -60,6 +61,7 @@ public:
     bool hasSettings;         /*!< Should be \b true if plugin has settings dialog, otherwise \b false */
     bool noInput;             /*!< Should be \b true if plugin has own input, otherwise \b false */
     bool noOutput;            /*!< Should be \b true if plugin has own output, otherwise \b false */
+    int priority;             /*!< Decoder priority. Decoders with lowest value will be used first */
 };
 /*! @brief Input plugin interface (decoder factory).
  * @author Ilya Kotov <forkotov02@hotmail.ru>
@@ -120,6 +122,6 @@ public:
     virtual QTranslator *createTranslator(QObject *parent) = 0;
 };
 
-Q_DECLARE_INTERFACE(DecoderFactory, "DecoderFactory/1.0");
+Q_DECLARE_INTERFACE(DecoderFactory, "DecoderFactory/1.0")
 
 #endif
