@@ -15,11 +15,12 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QFile>
 #include <QFileInfo>
+#include <QBuffer>
 #include <QMutexLocker>
 #include "decoder.h"
 #include "decoderfactory.h"
@@ -54,7 +55,7 @@ QList <FileInfo *> MetaDataManager::createPlayList(const QString &fileName, bool
     {
         if(!QFile::exists(fileName))
             return list;
-        if((fact = Decoder::findByPath(fileName)))
+        else if((fact = Decoder::findByPath(fileName, m_settings->determineFileTypeByContent())))
             return fact->createPlayList(fileName, useMetaData);
         else if((efact = AbstractEngine::findByPath(fileName)))
             return efact->createPlayList(fileName, useMetaData);
@@ -86,7 +87,7 @@ MetaDataModel* MetaDataManager::createMetaDataModel(const QString &path, QObject
     {
         if(!QFile::exists(path))
             return 0;
-        if((fact = Decoder::findByPath(path)))
+        else if((fact = Decoder::findByPath(path, m_settings->determineFileTypeByContent())))
             return fact->createMetaDataModel(path, parent);
         else if((efact = AbstractEngine::findByPath(path)))
             return efact->createMetaDataModel(path, parent);
@@ -140,6 +141,8 @@ QStringList MetaDataManager::nameFilters() const
         if (AbstractEngine::isEnabled(fact))
             filters << fact->properties().filters;
     }
+    if(m_settings->determineFileTypeByContent())
+        filters << "*";
     return filters;
 }
 
