@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QDir>
@@ -24,10 +24,6 @@
 #include <QLocale>
 #include <QByteArray>
 
-#ifndef QMMP_STR_VERSION
-#define QMMP_STR_VERSION "0.4.0"
-#endif
-
 #ifndef LIB_DIR
 #define LIB_DIR "/lib"
 #endif
@@ -48,11 +44,18 @@ void Qmmp::setConfigFile(const QString &path)
 
 const QString Qmmp::strVersion()
 {
+    QString ver = QString("%1.%2.%3")
+            .arg(QMMP_VERSION_MAJOR)
+            .arg(QMMP_VERSION_MINOR)
+            .arg(QMMP_VERSION_PATCH);
+#if !QMMP_VERSION_STABLE
 #ifdef SVN_REVISION
-    return QString("%1-%2").arg(QMMP_STR_VERSION).arg(SVN_REVISION);
+    ver += "-"SVN_REVISION;
 #else
-    return QMMP_STR_VERSION;
+    ver += "-svn";
 #endif
+#endif
+    return ver;
 }
 
 const QString Qmmp::pluginsPath()
