@@ -15,13 +15,13 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QMetaType>
 #include <QIODevice>
 #include <QFile>
-#include "replaygain.h"
+#include "replaygain_p.h"
 #include "effect.h"
 #include "buffer.h"
 #include "decoder.h"
@@ -29,8 +29,8 @@
 #include "decoderfactory.h"
 #include "effectfactory.h"
 #include "inputsource.h"
-#include "audioconverter.h"
-#include "qmmpaudioengine.h"
+#include "audioconverter_p.h"
+#include "qmmpaudioengine_p.h"
 #include "metadatamanager.h"
 
 
@@ -105,8 +105,8 @@ bool QmmpAudioEngine::enqueue(InputSource *source)
 
     DecoderFactory *factory = 0;
 
-    if(!source->url().contains("://"))
-        factory = Decoder::findByPath(source->url());
+    if(!factory && !source->url().contains("://"))
+        factory = Decoder::findByPath(source->url(), m_settings->determineFileTypeByContent());
     if(!factory)
         factory = Decoder::findByMime(source->contentType());
     if(!factory && source->ioDevice() && source->url().contains("://")) //ignore content of local files
@@ -294,7 +294,7 @@ void QmmpAudioEngine::finish()
         m_output->finish();
         m_output->mutex()->unlock();
     }
-    emit playbackFinished();
+    StateHandler::instance()->sendFinished();
 }
 
 void QmmpAudioEngine::updateReplayGainSettings()
@@ -324,13 +324,13 @@ void QmmpAudioEngine::run()
     m_replayGain->setReplayGainInfo(m_decoder->replayGainInfo());
     mutex()->unlock();
     m_output->start();
+    StateHandler::instance()->dispatch(Qmmp::Playing);
     sendMetaData();
 
     while (! m_done && ! m_finish)
     {
         mutex()->lock ();
-        // decode
-
+        //seek
         if (m_seekTime >= 0)
         {
             m_decoder->seek(m_seekTime);
@@ -340,7 +340,15 @@ void QmmpAudioEngine::run()
             m_output->recycler()->mutex()->unlock ();
             m_output_at = 0;
         }
+        //metadata
+        if(m_decoder->hasMetaData())
+            StateHandler::instance()->dispatch(m_decoder->takeMetaData());
+        if(m_inputs[m_decoder]->hasMetaData())
+            StateHandler::instance()->dispatch(m_inputs[m_decoder]->takeMetaData());
+        if(m_inputs[m_decoder]->hasStreamInfo())
+            StateHandler::instance()->dispatch(m_inputs[m_decoder]->takeStreamInfo());
 
+        // decode
         len = m_decoder->read((char *)(m_output_buf + m_output_at), m_output_size - m_output_at);
 
         if (len > 0)
@@ -356,11 +364,12 @@ void QmmpAudioEngine::run()
             {
                 m_next = false;
                 qDebug("QmmpAudioEngine: switching to the next track");
-                emit playbackFinished();
+                StateHandler::instance()->sendFinished();
                 StateHandler::instance()->dispatch(Qmmp::Stopped); //fake stop/start cycle
                 StateHandler::instance()->dispatch(Qmmp::Buffering);
                 StateHandler::instance()->dispatch(Qmmp::Playing);
                 m_decoder->next();
+                m_replayGain->setReplayGainInfo(m_decoder->replayGainInfo());
                 m_output->seek(0); //reset counter
                 addOffset(); //offset
                 mutex()->unlock();
@@ -377,7 +386,7 @@ void QmmpAudioEngine::run()
                 prepareEffects(m_decoder);
                 if(m_ap == m_output->audioParameters())
                 {
-                    emit playbackFinished();
+                    StateHandler::instance()->sendFinished();
                     StateHandler::instance()->dispatch(Qmmp::Stopped); //fake stop/start cycle
                     StateHandler::instance()->dispatch(Qmmp::Buffering);
                     StateHandler::instance()->dispatch(Qmmp::Playing);
@@ -403,6 +412,7 @@ void QmmpAudioEngine::run()
                     if(m_output)
                     {
                         m_output->start();
+                        StateHandler::instance()->dispatch(Qmmp::Playing);
                         sendMetaData();
                         addOffset(); //offset
                         continue;
@@ -520,7 +530,8 @@ Output *QmmpAudioEngine::createOutput()
         StateHandler::instance()->dispatch(Qmmp::FatalError);
         return 0;
     }
-    if (!output->initialize())
+    if (!output->initialize(m_ap.sampleRate(), m_ap.channels(), m_ap.format()) ||
+            output->audioParameters() != m_ap) //TODO add soundconverter
     {
         qWarning("QmmpAudioEngine: unable to initialize output");
         delete output;
@@ -528,7 +539,6 @@ Output *QmmpAudioEngine::createOutput()
         StateHandler::instance()->dispatch(Qmmp::FatalError);
         return false;
     }
-    output->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
     if(m_output_buf)
         delete [] m_output_buf;
     m_bks = QMMP_BLOCK_FRAMES * m_ap.channels() * m_ap.sampleSize();
