@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include <QtGui>
@@ -26,21 +26,21 @@
 #include <iostream>
 #include <qmmp/qmmp.h>
 #include <qmmp/soundcore.h>
-#include <qmmpui/generalhandler.h>
+#include <qmmpui/uihelper.h>
 #include <qmmpui/mediaplayer.h>
 #include "commandlinemanager.h"
 
 using namespace std;
 
 QList<CommandLineOption *> *CommandLineManager::m_options = 0;
-QStringList CommandLineManager::m_files;
+QHash<CommandLineOption*, QString> *CommandLineManager::m_files = 0;
 
 void CommandLineManager::checkOptions()
 {
     if (!m_options)
     {
-        m_files.clear();
         m_options = new QList<CommandLineOption *>;
+        m_files = new QHash<CommandLineOption*, QString>;
 
         QDir pluginsDir (Qmmp::pluginsPath());
         pluginsDir.cd("CommandLineOptions");
@@ -60,7 +60,7 @@ void CommandLineManager::checkOptions()
             if (option)
             {
                 m_options->append(option);
-                m_files << pluginsDir.absoluteFilePath(fileName);
+                m_files->insert(option, pluginsDir.absoluteFilePath(fileName));
                 qApp->installTranslator(option->createTranslator(qApp));
             }
         }
@@ -70,7 +70,7 @@ void CommandLineManager::checkOptions()
 QString CommandLineManager::executeCommand(const QString& opt_str, const QStringList &args)
 {
     checkOptions();
-    if(!GeneralHandler::instance() || !SoundCore::instance() || !MediaPlayer::instance())
+    if(!UiHelper::instance() || !SoundCore::instance() || !MediaPlayer::instance())
     {
         qWarning("CommandLineManager: player objects are not created");
         return QString();
