@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,11 +15,10 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include <QDesktopServices>
 #include <QTextCodec>
-#include <QSettings>
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
@@ -27,9 +26,10 @@
 #include <qmmp/metadatamanager.h>
 #include <qmmp/metadatamodel.h>
 #include <qmmp/tagmodel.h>
+#include <qmmp/soundcore.h>
 #include "ui_detailsdialog.h"
 #include "playlistitem.h"
-#include "tageditor.h"
+#include "tageditor_p.h"
 #include "detailsdialog.h"
 
 DetailsDialog::DetailsDialog(PlayListItem *item, QWidget *parent)
@@ -93,6 +93,7 @@ void DetailsDialog:: on_directoryButton_clicked()
 
 void DetailsDialog::printInfo()
 {
+    SoundCore *core = SoundCore::instance();
     QList <FileInfo *> flist = MetaDataManager::instance()->createPlayList(m_path, true);
     QMap <Qmmp::MetaData, QString> metaData;
     if(!flist.isEmpty() && QFile::exists(m_item->url()))
@@ -114,6 +115,21 @@ void DetailsDialog::printInfo()
         formattedText += formatRow(tr("Track"), metaData[Qmmp::TRACK]);
     if(metaData[Qmmp::DISCNUMBER] != "0")
         formattedText += formatRow(tr("Disc number"), metaData[Qmmp::DISCNUMBER]);
+    //stream information
+    if(core->state() == Qmmp::Playing && core->url() == metaData.value(Qmmp::URL))
+    {
+        if(!core->streamInfo().isEmpty())
+        {
+            formattedText.append("<tr>");
+            formattedText.append("<td colspan=2>");
+            formattedText.append("<hr>");
+            formattedText.append("</td>");
+            formattedText.append("</tr>");
+
+            foreach(QString key, core->streamInfo().keys())
+                formattedText += formatRow(key, core->streamInfo().value(key));
+        }
+    }
     //audio info
     if(!m_metaDataModel)
     {
