@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #include <QWidget>
 #include <QFile>
@@ -26,18 +26,16 @@
 #include <QPluginLoader>
 #include <QApplication>
 #include <QTimer>
-#include <QSettings>
 #include <QBuffer>
 #include <QMetaType>
 #include <time.h>
 #include <qmmp/metadatamanager.h>
 #include "playlistparser.h"
 #include "playlistformat.h"
-#include "fileloader.h"
+#include "fileloader_p.h"
 #include "playlistitem.h"
-#include "playstate.h"
+#include "playstate_p.h"
 #include "detailsdialog.h"
-#include "playlistsettings.h"
 #include "playlistmodel.h"
 
 
@@ -311,10 +309,13 @@ bool PlayListModel::contains(const QString &url)
     return false;
 }
 
-void PlayListModel::setSelected(int row, bool yes)
+void PlayListModel::setSelected(int row, bool selected)
 {
     if (m_items.count() > row && row >= 0)
-        m_items.at(row)->setSelected(yes);
+    {
+        m_items.at(row)->setSelected(selected);
+        emit listChanged();
+    }
 }
 
 void PlayListModel::removeSelected()
@@ -403,7 +404,8 @@ void PlayListModel::removeSelection(bool inverted)
     if (select_after_delete >= m_items.count())
         select_after_delete = m_items.count() - 1;
 
-    setSelected(select_after_delete,true);
+    if(select_after_delete != -1)
+        m_items.at(select_after_delete)->setSelected(true);
 
     m_play_state->prepare();
 
@@ -466,7 +468,7 @@ void PlayListModel::moveItems(int from, int to)
     if (from == to)
         return;
 
-    QList<int> selected_rows = getSelectedRows();
+    QList<int> selected_rows = selectedRows();
 
     if (!(bottommostInSelection(from) == INVALID_ROW ||
             from == INVALID_ROW ||
@@ -527,11 +529,11 @@ const SimpleSelection& PlayListModel::getSelection(int row)
     m_selection.m_top = topmostInSelection(row);
     m_selection.m_anchor = row;
     m_selection.m_bottom = bottommostInSelection(row);
-    m_selection.m_selected_rows = getSelectedRows();
+    m_selection.m_selected_rows = selectedRows();
     return m_selection;
 }
 
-QList<int> PlayListModel::getSelectedRows() const
+QList<int> PlayListModel::selectedRows() const
 {
     QList<int>selected_rows;
     for (int i = 0;i<m_items.count();i++)
@@ -544,7 +546,7 @@ QList<int> PlayListModel::getSelectedRows() const
     return selected_rows;
 }
 
-QList< PlayListItem * > PlayListModel::getSelectedItems() const
+QList< PlayListItem * > PlayListModel::selectedItems() const
 {
     QList<PlayListItem*>selected_items;
     for (int i = 0;i<m_items.count();i++)
@@ -559,7 +561,7 @@ QList< PlayListItem * > PlayListModel::getSelectedItems() const
 
 void PlayListModel::addToQueue()
 {
-    QList<PlayListItem*> selected_items = getSelectedItems();
+    QList<PlayListItem*> selected_items = selectedItems();
     foreach(PlayListItem* file,selected_items)
         setQueued(file);
     emit listChanged();
@@ -637,6 +639,17 @@ static bool _titleGreaterComparator(PlayListItem* s1,PlayListItem* s2)
 {
     return QString::localeAwareCompare (s1->value(Qmmp::TITLE), s2->value(Qmmp::TITLE)) > 0;
 }
+
+//by album+disc
+static bool _discnumberLessComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QString::localeAwareCompare (s1->value(Qmmp::DISCNUMBER), s2->value(Qmmp::DISCNUMBER)) < 0;
+}
+
+static bool _discnumberGreaterComparator(PlayListItem* s1,PlayListItem* s2)
+{
+    return QString::localeAwareCompare (s1->value(Qmmp::DISCNUMBER), s2->value(Qmmp::DISCNUMBER)) > 0;
+}
 //by album
 static bool _albumLessComparator(PlayListItem* s1,PlayListItem* s2)
 {
@@ -720,6 +733,10 @@ void PlayListModel::doSort(int sort_mode,QList<PlayListItem*>& list_to_sort)
         compareLessFunc = _titleLessComparator;
         compareGreaterFunc = _titleGreaterComparator;
         break;
+    case DISCNUMBER:
+        compareLessFunc = _discnumberLessComparator;
+        compareGreaterFunc = _discnumberGreaterComparator;
+        break;
     case ALBUM:
         compareLessFunc = _albumLessComparator;
         compareGreaterFunc = _albumGreaterComparator;
@@ -767,8 +784,8 @@ void PlayListModel::doSort(int sort_mode,QList<PlayListItem*>& list_to_sort)
 
 void PlayListModel::sortSelection(int mode)
 {
-    QList<PlayListItem*>selected_items = getSelectedItems();
-    QList<int>selected_rows = getSelectedRows();
+    QList<PlayListItem*>selected_items = selectedItems();
+    QList<int>selected_rows = selectedRows();
 
     doSort(mode,selected_items);
 
@@ -922,7 +939,7 @@ void PlayListModel::clearQueue()
 
 void PlayListModel::stopAfterSelected()
 {
-    QList<PlayListItem*> selected_items = getSelectedItems();
+    QList<PlayListItem*> selected_items = selectedItems();
     if(!m_queued_songs.isEmpty())
     {
         m_stop_item = m_stop_item != m_queued_songs.last() ? m_queued_songs.last() : 0;
