@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #ifndef PLAYLISTMODEL_H
 #define PLAYLISTMODEL_H
@@ -163,9 +163,9 @@ public:
     /*!
      * Sets the selected state of the item to \b select
      * @param row Number of item.
-     * @param select Selection state (\b true - select, \b false - unselect)
+     * @param selected Selection state (\b true - select, \b false - unselect)
      */
-    void setSelected(int row, bool select);
+    void setSelected(int row, bool selected = true);
     /*!
      * Advances to the next item. Returns \b false if next iten doesn't exist,
      * otherwise returns \b true
@@ -183,7 +183,7 @@ public:
      */
     QStringList getTitles(int first,int last);
     /*!
-     * Returns a list of the formated durations.
+     * Returns a list of the formatted durations.
      * @param first First item.
      * @param last Last item.
      */
@@ -224,11 +224,11 @@ public:
     /*!
      * Returns list with selected rows indexes.
      */
-    QList<int> getSelectedRows() const;
+    QList<int> selectedRows() const;
     /*!
      * Returns list of \b PlayListItem pointers that are selected.
      */
-    QList<PlayListItem*> getSelectedItems() const;
+    QList<PlayListItem*> selectedItems() const;
     /*!
      * Returns list of all \b PlayListItem pointers.
      */
@@ -282,6 +282,7 @@ public:
     {
         TITLE,             /*!< by title */
         ALBUM,             /*!< by album */
+        DISCNUMBER,        /*!< by discnumber */
         ARTIST,            /*!< by artist */
         FILENAME,          /*!< by file name */
         PATH_AND_FILENAME, /*!< by path and file name */
