@@ -15,14 +15,13 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 #ifndef PLAYLISTPARSER_H
 #define PLAYLISTPARSER_H
 
 #include <QObject>
-
-class PlaylistFormat;
+#include "playlistformat.h"
 
 /*! @brief The PlaylistParser class provides a simple api to access playlist format plugins.
  * @author Ilya Kotov <forkotov02@hotmail.ru>
